==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebTimeSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescriptionMetadata } from "./WebSummaryOperandDescriptionMetadata";
import { WebTimeSummaryOperandDescription } from "./WebTimeSummaryOperandDescription";
/**
 * @hidden
 */
export let WebTimeSummaryOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTimeSummaryOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebTimeSummaryOperandDescriptionMetadata.a == null) {
                WebTimeSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTimeSummaryOperandDescriptionMetadata.c(WebTimeSummaryOperandDescriptionMetadata.a);
            }
            if (a.k(WebTimeSummaryOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebTimeSummaryOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebSummaryOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TimeSummaryOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebTimeSummaryOperandDescriptionMetadata.b(a);
            a.ad("WebTimeSummaryOperand", () => new WebTimeSummaryOperandDescription());
            a.ac("WebTimeSummaryOperand", WebTimeSummaryOperandDescriptionMetadata.a);
        }
    }
    WebTimeSummaryOperandDescriptionMetadata.$t = markType(WebTimeSummaryOperandDescriptionMetadata, 'WebTimeSummaryOperandDescriptionMetadata');
    WebTimeSummaryOperandDescriptionMetadata.a = null;
    return WebTimeSummaryOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebTimeSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescriptionMetadata } from "./WebSummaryOperandDescriptionMetadata";
import { WebTimeSummaryOperandDescription } from "./WebTimeSummaryOperandDescription";
/**
 * @hidden
 */
export let WebTimeSummaryOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTimeSummaryOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebTimeSummaryOperandDescriptionMetadata.a == null) {
                WebTimeSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTimeSummaryOperandDescriptionMetadata.c(WebTimeSummaryOperandDescriptionMetadata.a);
            }
            if (a.k(WebTimeSummaryOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTimeSummaryOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebSummaryOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TimeSummaryOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebTimeSummaryOperandDescriptionMetadata.b(a);
            a.ae("WebTimeSummaryOperand", () => new WebTimeSummaryOperandDescription());
            a.ad("WebTimeSummaryOperand", WebTimeSummaryOperandDescriptionMetadata.a);
        }
    }
    WebTimeSummaryOperandDescriptionMetadata.$t = markType(WebTimeSummaryOperandDescriptionMetadata, 'WebTimeSummaryOperandDescriptionMetadata');
    WebTimeSummaryOperandDescriptionMetadata.a = null;
    return WebTimeSummaryOperandDescriptionMetadata;
})();
